@@ -17,7 +17,7 @@ enum keyWords
     LABEL, LABELPOS, LABEL_BODY, LABEL_STRING, LAMBERT, LANGUAGE, LATITUDE, LATLON, LBR, LEFT, LIGHT_TIME, LOCALTIME, LOGMAGSTEP, LONGITUDE, 
     MAGNIFY, MAJOR, MAKECLOUDMAPS, MAP_BOUNDS, MARKER_BOUNDS, MARKER_COLOR, MARKER_FILE, MARKER_FONT, MARKER_FONTSIZE, MAX_RAD_FOR_LABEL, MIN_RAD_FOR_LABEL, MAX_RAD_FOR_MARKERS, MIN_RAD_FOR_MARKERS, MERCATOR, MOLLWEIDE, MULTIPLE,
     NAME, NIGHT_MAP, NORTH, NUM_TIMES, 
-    ORBIT, ORBIT_COLOR, ORIGIN, ORIGINFILE, ORTHOGRAPHIC, OUTPUT, OUTPUT_START_INDEX, 
+    ORBIT, ORBIT_COLOR, ORIGIN, ORIGINFILE, ORTHOGRAPHIC, OUTLINED, OUTPUT, OUTPUT_MAP_RECT, OUTPUT_START_INDEX, 
     PANGO, PATH, PATH_RELATIVE_TO, PETERS, POLYCONIC, POSITION, POST_COMMAND, PREV_COMMAND, PROJECTION, PROJECTIONPARAMETER, 
     QUALITY, 
     RADIUS, RANDOM, RANDOM_ORIGIN, RANDOM_TARGET, RANGE, RECTANGULAR, RIGHT, ROOT, ROTATE, 
@@ -46,7 +46,7 @@ const char * const keyWordString[LAST_WORD] =
     "LABEL", "LABELPOS", "LABEL_BODY", "LABEL_STRING", "LAMBERT", "LANGUAGE", "LATITUDE", "LATLON", "LBR", "LEFT", "LIGHT_TIME", "LOCALTIME", "LOGMAGSTEP", "LONGITUDE", 
     "MAGNIFY", "MAJOR", "MAKECLOUDMAPS", "MAP_BOUNDS", "MARKER_BOUNDS", "MARKER_COLOR", "MARKER_FILE", "MARKER_FONT", "MARKER_FONTSIZE", "MAX_RAD_FOR_LABEL", "MIN_RAD_FOR_LABEL", "MAX_RAD_FOR_MARKERS", "MIN_RAD_FOR_MARKERS", "MERCATOR", "MOLLWEIDE", "MULTIPLE",
     "NAME", "NIGHT_MAP", "NORTH", "NUM_TIMES", 
-    "ORBIT", "ORBIT_COLOR", "ORIGIN", "ORIGINFILE", "ORTHOGRAPHIC", "OUTPUT", "OUTPUT_START_INDEX", 
+    "ORBIT", "ORBIT_COLOR", "ORIGIN", "ORIGINFILE", "ORTHOGRAPHIC", "OUTLINED", "OUTPUT", "OUTPUT_MAP_RECT", "OUTPUT_START_INDEX", 
     "PANGO", "PATH", "PATH_RELATIVE_TO", "PETERS", "POLYCONIC", "POSITION", "POST_COMMAND", "PREV_COMMAND", "PROJECTION", "PROJECTIONPARAMETER", 
     "QUALITY", 
     "RADIUS", "RANDOM", "RANDOM_ORIGIN", "RANDOM_TARGET", "RANGE", "RECTANGULAR", "RIGHT", "ROOT", "ROTATE", 
