@@ -9,10 +9,10 @@ class Text : public Annotation
 {
  public:
     Text(const unsigned char color[3], 
-	 const int x, const int y, 
-	 const int iconWidth, const int iconHeight,
-	 const int align, 
-	 const std::string &text);
+         const int x, const int y, 
+         const int iconWidth, const int iconHeight,
+         const int align, 
+         const std::string &text);
 
     virtual ~Text();
 
@@ -23,6 +23,8 @@ class Text : public Annotation
     void Font(const std::string &font) { font_.assign(font); };
     void FontSize(const int fontSize) { fontSize_ = fontSize; };
 
+    void Outline(const bool b) { outlined_ = b; };
+
     int Overhang(const int width, const int height);
     int Overlap(const Text *const t);
 
@@ -50,6 +52,8 @@ class Text : public Annotation
     int xOffset_;
     int yOffset_;
 
+    bool outlined_;
+
     std::string text_;
     int textHeight_;
     int textWidth_;
