@@ -8,6 +8,10 @@ using namespace std;
 #include "parseColor.h"
 #include "xpUtil.h"
 
+// sloppy, but it's an easy way to set the comment marker as a line
+// terminator
+static bool commentEndsLine = true;
+
 bool
 isDelimiter(char c)
 {
@@ -18,7 +22,11 @@ bool
 isEndOfLine(char c)
 {
     // 13 is DOS end-of-line, 28 is the file separator
-    return(c == '#' || c == '\0' || c == 13 || c == 28); 
+    bool returnValue = (c == '\0' || c == 13 || c == 28);
+
+    if (commentEndsLine) returnValue = (c == '#' || returnValue);
+
+    return(returnValue); 
 }
 
 static void
@@ -48,10 +56,10 @@ skipPastToken(int &i, const char *line)
     }
 }
 
+// If the line contains 'key', return everything between 'key' and 'endChar'
 static bool
 getValue(const char *line, int &i, const char *key, const char endChar, 
          char *&returnstring)
-// If the line contains 'key', return everything between 'key' and 'endChar'
 {
     const unsigned int length = strlen(key);
     if (strncmp(line + i, key, length) == 0)
@@ -68,6 +76,19 @@ getValue(const char *line, int &i, const char *key, const char endChar,
     return(false);
 }
 
+// If the line contains 'key', return everything between 'key' and
+// 'endChar' comment markers are allowed in the string.  Use this for
+// reading marker labels.
+static bool
+getValueIncludingComment(const char *line, int &i, const char *key, 
+                       const char endChar, char *&returnstring)
+{
+    commentEndsLine = false;
+    bool returnValue = getValue(line, i, key, endChar, returnstring);
+    commentEndsLine = true;
+    return(returnValue);
+}
+
 static bool
 getValueAfter(const char *line, int &i, const char *key, const char endChar,
          char *&returnstring)
@@ -214,7 +235,6 @@ parse(int &i, const char *line, char *&returnString)
     // This line must be after all other "marker_" keywords, because
     // it gobbles all forms
     else if (getValueAfter(line, i, "marker_", '=', returnString))
-
         returnVal = MARKER_FILE;
     else if (getValue(line, i, "map=", returnString))
         returnVal = DAY_MAP;
@@ -228,9 +248,9 @@ parse(int &i, const char *line, char *&returnString)
         returnVal = MAX_RAD_FOR_MARKERS;
     else if (getValue(line, i, "min_radius=", returnString))
         returnVal = MIN_RAD_FOR_MARKERS;
-    else if (getValue(line, i, "\"", '"', returnString))
+    else if (getValueIncludingComment(line, i, "\"", '"', returnString))
         returnVal = NAME;
-    else if (getValue(line, i, "{", '}', returnString))
+    else if (getValueIncludingComment(line, i, "{", '}', returnString))
         returnVal = NAME;
     else if (getValue(line, i, "night_map=", returnString))
         returnVal = NIGHT_MAP;
@@ -249,6 +269,8 @@ parse(int &i, const char *line, char *&returnString)
     }
     else if (getValue(line, i, "relative_to=", returnString))
         returnVal = ORIGIN;
+    else if (getValue(line, i, "outlined=", returnString))
+        returnVal = OUTLINED;
     else if (getValue(line, i, "position=", returnString))
         returnVal = POSITION;
     else if (getValue(line, i, "radius=", returnString))
